<?php

namespace Shopping\Material\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Shopping\Material\Interfaces\MaterialRepositoryInterface;

class MaterialPublicController extends BaseController
{
    // use MaterialWorkflow;

    /**
     * Constructor.
     *
     * @param type \Shopping\Material\Interfaces\MaterialRepositoryInterface $material
     *
     * @return type
     */
    public function __construct(MaterialRepositoryInterface $material)
    {
        $this->repository = $material;
        parent::__construct();
    }

    /**
     * Show material's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $materials = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$material::$material.names'))
            ->view('$material::public.material.index')
            ->data(compact('$materials'))
            ->output();
    }

    /**
     * Show material's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $materials = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$material::$material.names'))
            ->view('$material::public.material.index')
            ->data(compact('$materials'))
            ->output();
    }

    /**
     * Show material.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $material = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$material->name . trans('$material::$material.name'))
            ->view('$material::public.material.show')
            ->data(compact('$material'))
            ->output();
    }

}
