<?php

namespace Shopping\Material\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Material\Models\Material;

class MaterialPolicy
{

    /**
     * Determine if the given user can view the material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function view(UserPolicy $user, Material $material)
    {
        if ($user->canDo('material.material.view') && $user->isAdmin()) {
            return true;
        }

        return $material->user_id == user_id() && $material->user_type == user_type();
    }

    /**
     * Determine if the given user can create a material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('material.material.create');
    }

    /**
     * Determine if the given user can update the given material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function update(UserPolicy $user, Material $material)
    {
        if ($user->canDo('material.material.edit') && $user->isAdmin()) {
            return true;
        }

        return $material->user_id == user_id() && $material->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Material $material)
    {
        return $material->user_id == user_id() && $material->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Material $material)
    {
        if ($user->canDo('material.material.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given material.
     *
     * @param UserPolicy $user
     * @param Material $material
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Material $material)
    {
        if ($user->canDo('material.material.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
