<?php

namespace Shopping\Material\Providers;

use Illuminate\Support\ServiceProvider;

class MaterialServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'material');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'material');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('shopping.material', function ($app) {
            return $this->app->make('Shopping\Material\Material');
        });

                // Bind Material to repository
        $this->app->bind(
            'Shopping\Material\Interfaces\MaterialRepositoryInterface',
            \Shopping\Material\Repositories\Eloquent\MaterialRepository::class
        );

        $this->app->register(\Shopping\Material\Providers\AuthServiceProvider::class);
                $this->app->register(\Shopping\Material\Providers\EventServiceProvider::class);
        
        $this->app->register(\Shopping\Material\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['shopping.material'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('shopping/material.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/material')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/material')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
